@@ -650,6 +650,7 @@ main(int argc,char **argv)
     
     /* Catenate time-stamped command line to "history" global attribute */
     if(HISTORY_APPEND) (void)nco_hst_att_cat(out_id,cmd_ln);
+    if(HISTORY_APPEND) (void)nco_vrs_att_cat(out_id);
     
     if(thr_nbr > 0 && HISTORY_APPEND) (void)nco_thr_att_cat(out_id,thr_nbr);
     
@@ -954,6 +955,8 @@ main(int argc,char **argv)
     /* ncflint-specific memory */
     if(fl_in_1) fl_in_1=(char *)nco_free(fl_in_1);
     if(fl_in_2) fl_in_2=(char *)nco_free(fl_in_2);
+    if(in_id_arr_1) in_id_arr_1=(int *)nco_free(in_id_arr_1);
+    if(in_id_arr_2) in_id_arr_2=(int *)nco_free(in_id_arr_2);
     var_prc_1=(var_sct **)nco_free(var_prc_1);
     var_prc_2=(var_sct **)nco_free(var_prc_2);
     if(wgt_1) wgt_1=(var_sct *)nco_var_free(wgt_1);
