@@ -18,15 +18,131 @@
 # define strtoll  _strtoi64
 #endif /* !_MSC_VER */
 
-void
+nco_bool /* [flg] Attribute was changed */
+nco_aed_prc_wrp /* [fnc] Expand regular expressions then pass attribute edits to nco_aed_prc() */
+(const int nc_id, /* I [id] Input netCDF file ID */
+ const int var_id, /* I [id] ID of variable on which to perform attribute editing */
+ const aed_sct aed) /* I [sct] Attribute-edit information */
+{
+  /* Purpose: Wrapper for nco_aed_prc(), which processes single attribute edit for single variable
+     This wrapper passes its arguments straight throught to nco_aed_prc() with one exception---
+     it unrolls attribute name that are regular expression into multiple calls to nco_aed_prc() */
+  const char fnc_nm[]="nco_aed_prc_wrp()"; /* [sng] Function name */
+  nco_bool flg_chg=False; /* [flg] Attribute was altered */
+
+  if(!strpbrk(aed.att_nm,".*^$\\[]()<>+?|{}")){
+    // const char foo[]="foo {{";
+    /* NB: previous line confuses Emacs C-mode indenter. Restore with isolated parenthesis? */
+    /* If attribute name is not regular expression, call single attribute routine then return */
+    flg_chg|=nco_aed_prc(nc_id,var_id,aed);
+    return flg_chg; /* [flg] Attribute was altered */
+  } /* !rx */
+  
+#ifndef NCO_HAVE_REGEX_FUNCTIONALITY
+  (void)fprintf(stdout,"%s: ERROR: Sorry, wildcarding (extended regular expression matches to attributes) was not built into this NCO executable, so unable to compile regular expression \"%s\".\nHINT: Make sure libregex.a is on path and re-build NCO.\n",nco_prg_nm_get(),aed.att_nm);
+  nco_exit(EXIT_FAILURE);
+#else /* NCO_HAVE_REGEX_FUNCTIONALITY */
+  /* aed.att_nm is regular expression */
+
+  aed_sct aed_swp; /* [sct] Attribute-edit information */
+
+  char *rx_sng; /* [sng] Regular expression pattern */
+
+  int err_id;
+  int flg_cmp; /* Comparison flags */
+  int flg_exe; /* Execution flages */
+  int mch_nbr=0;
+  
+  regex_t *rx;
+  regmatch_t *result;
+
+  size_t rx_prn_sub_xpr_nbr;
+
+  rx_sng=aed.att_nm;
+  rx=(regex_t *)nco_malloc(sizeof(regex_t));
+
+  /* Choose RE_SYNTAX_POSIX_EXTENDED regular expression type */
+  flg_cmp=(REG_EXTENDED | REG_NEWLINE);
+  /* Set execution flags */
+  flg_exe=0;
+
+  /* Compile regular expression */
+  if((err_id=regcomp(rx,rx_sng,flg_cmp))){ /* Compile regular expression */
+    char const * rx_err_sng;  
+    /* POSIX regcomp return error codes */
+    switch(err_id){
+    case REG_BADPAT: rx_err_sng="Invalid pattern"; break;  
+    case REG_ECOLLATE: rx_err_sng="Not implemented"; break;
+    case REG_ECTYPE: rx_err_sng="Invalid character class name"; break;
+    case REG_EESCAPE: rx_err_sng="Trailing backslash"; break;
+    case REG_ESUBREG: rx_err_sng="Invalid back reference"; break;
+    case REG_EBRACK: rx_err_sng="Unmatched left bracket"; break;
+    case REG_EPAREN: rx_err_sng="Parenthesis imbalance"; break;
+    case REG_EBRACE: rx_err_sng="Unmatched {"; break;
+    case REG_BADBR: rx_err_sng="Invalid contents of { }"; break;
+    case REG_ERANGE: rx_err_sng="Invalid range end"; break;
+    case REG_ESPACE: rx_err_sng="Ran out of memory"; break;
+    case REG_BADRPT: rx_err_sng="No preceding re for repetition op"; break;
+    default: rx_err_sng="Invalid pattern"; break;  
+    } /* end switch */
+    (void)fprintf(stdout,"%s: ERROR %s error in regular expression \"%s\" %s\n",nco_prg_nm_get(),fnc_nm,rx_sng,rx_err_sng); 
+    nco_exit(EXIT_FAILURE);
+  } /* end if err */
+
+  rx_prn_sub_xpr_nbr=rx->re_nsub+1L; /* Number of parenthesized sub-expressions */
+
+  /* Search string */
+  result=(regmatch_t *)nco_malloc(sizeof(regmatch_t)*rx_prn_sub_xpr_nbr);
+
+  /* Regular expression is ready to use */
+  char **att_nm_lst;
+  int att_idx;
+  int att_nbr;
+  int grp_id;
+  grp_id=nc_id;
+  /* Get number of attributes for variable/group */
+  (void)nco_inq_varnatts(grp_id,var_id,&att_nbr);
+
+  /* 20150629: Read in all attribute names before any editing 
+     This is because creation or deletion of attributes can change their number
+     According to the netCDF documentation, "The number of an attribute is more volatile than the name, since it can change when other attributes of the same variable are deleted. This is why an attribute number is not called an attribute ID." */
+  att_nm_lst=(char **)nco_malloc(att_nbr*sizeof(char *));
+  for(att_idx=0;att_idx<att_nbr;att_idx++){
+    att_nm_lst[att_idx]=(char *)nco_malloc((NC_MAX_NAME+1L)*sizeof(char));
+    nco_inq_attname(grp_id,var_id,att_idx,att_nm_lst[att_idx]);
+  } /* !att */
+
+  /* Check each attribute for match to rx */
+  for(att_idx=0;att_idx<att_nbr;att_idx++){
+    if(!regexec(rx,att_nm_lst[att_idx],rx_prn_sub_xpr_nbr,result,flg_exe)){
+      mch_nbr++;
+      /* Swap original attibute name (the regular expression) with its current match */
+      aed_swp=aed;
+      aed_swp.att_nm=att_nm_lst[att_idx];
+      flg_chg|=nco_aed_prc(nc_id,var_id,aed_swp);
+    } /* !mch */
+  } /* !att */
+
+  if(att_nm_lst) att_nm_lst=nco_sng_lst_free(att_nm_lst,att_nbr);
+  if(!mch_nbr) (void)fprintf(stdout,"%s: WARNING: Regular expression \"%s\" does not match any attribute\nHINT: See regular expression syntax examples at http://nco.sf.net/nco.html#rx\n",nco_prg_nm_get(),aed.att_nm); 
+
+  regfree(rx); /* Free regular expression data structure */
+  rx=(regex_t *)nco_free(rx);
+  result=(regmatch_t *)nco_free(result);
+#endif /* NCO_HAVE_REGEX_FUNCTIONALITY */
+  
+ return flg_chg; /* [flg] Attribute was altered */
+} /* end nco_aed_prc() */
+
+ nco_bool /* [flg] Attribute was changed */
 nco_aed_prc /* [fnc] Process single attribute edit for single variable */
 (const int nc_id, /* I [id] Input netCDF file ID */
  const int var_id, /* I [id] ID of variable on which to perform attribute editing */
- const aed_sct aed) /* I [sct] Structure containing information necessary to edit */
+ const aed_sct aed) /* I [sct] Attribute-edit information */
 {
   /* Purpose: Process single attribute edit for single variable */
   
-  /* If var_id == NC_GLOBAL ( = -1) then global attribute will be edited */
+  /* If var_id == NC_GLOBAL == -1 then edit global/group attribute */
   
   const char fnc_nm[]="nco_aed_prc()"; /* [sng] Function name */
   
@@ -46,6 +162,7 @@ nco_aed_prc /* [fnc] Process single attribute edit for single variable */
   long att_sz;
   
   nc_type att_typ;
+  nco_bool flg_chg=False; /* [flg] Attribute was altered */
   
   void *att_val_new=NULL;
   
@@ -240,7 +357,7 @@ nco_aed_prc /* [fnc] Process single attribute edit for single variable */
      aed.att_nm && /* 20130419: Verify att_nm exists before using it in strcmp() below. att_nm does not exist when user leaves field blank. Fix provided by Etienne Tourigny. */
      !strcmp(aed.att_nm,nco_mss_val_sng_get()) && /* ... attribute is missing value and ... */
      aed.mode != aed_delete &&  /* ... we are not deleting attribute */
-     NC_LIB_VERSION < 434){ /* netCDF library does not contain fix to NCF-187 */
+     NC_LIB_VERSION <= 440){ /* netCDF library does not contain fix to NCF-187 */
     /* Rename existing attribute to netCDF4-safe name 
        After modifying missing value attribute with netCDF4-safe name below, 
        we will rename attribute to original missing value name. */
@@ -272,34 +389,47 @@ nco_aed_prc /* [fnc] Process single attribute edit for single variable */
 		   (void *)aed.val.vp,
 		   aed.sz*nco_typ_lng(aed.type));
       rcd+=nco_put_att(nc_id,var_id,aed.att_nm,aed.type,att_sz+aed.sz,att_val_new);
+      flg_chg=True; /* [flg] Attribute was altered */
       att_val_new=nco_free(att_val_new);
     }else{
       /* Create new attribute */
       rcd+=nco_put_att(nc_id,var_id,aed.att_nm,aed.type,aed.sz,aed.val.vp);
+      flg_chg=True; /* [flg] Attribute was altered */
     } /* end else */
     break;
   case aed_create:	
-    if(rcd_inq_att != NC_NOERR) rcd+=nco_put_att(nc_id,var_id,aed.att_nm,aed.type,aed.sz,aed.val.vp);  
+    if(rcd_inq_att != NC_NOERR){
+      rcd+=nco_put_att(nc_id,var_id,aed.att_nm,aed.type,aed.sz,aed.val.vp);  
+      flg_chg=True; /* [flg] Attribute was altered */
+    } /* endif */
     break;
   case aed_delete:	
     /* Delete specified attribute if attribute name was specified... */
     if(aed.att_nm){
       /* ...and if attribute is known to exist from previous inquire call... */
-      if(rcd_inq_att == NC_NOERR) rcd+=nco_del_att(nc_id,var_id,aed.att_nm);
+      if(rcd_inq_att == NC_NOERR){
+	rcd+=nco_del_att(nc_id,var_id,aed.att_nm);
+	flg_chg=True; /* [flg] Attribute was altered */
+      } /* endif */
     }else{
       /* ...else delete all attributes for this variable... */
       while(nbr_att){
 	rcd+=nco_inq_attname(nc_id,var_id,nbr_att-1,att_nm);
 	rcd+=nco_del_att(nc_id,var_id,att_nm);
 	nbr_att--;
+	flg_chg=True; /* [flg] Attribute was altered */
       } /* end while */
     } /* end else */
     break;
   case aed_modify:	
-    if(rcd_inq_att == NC_NOERR) rcd+=nco_put_att(nc_id,var_id,aed.att_nm,aed.type,aed.sz,aed.val.vp);
+    if(rcd_inq_att == NC_NOERR){
+      rcd+=nco_put_att(nc_id,var_id,aed.att_nm,aed.type,aed.sz,aed.val.vp);
+      flg_chg=True; /* [flg] Attribute was altered */
+    } /* endif */
     break;
   case aed_overwrite:	
     rcd+=nco_put_att(nc_id,var_id,aed.att_nm,aed.type,aed.sz,aed.val.vp);  
+    flg_chg=True; /* [flg] Attribute was altered */
     break;
   default: 
     break;
@@ -315,8 +445,187 @@ nco_aed_prc /* [fnc] Process single attribute edit for single variable */
 
   if(rcd != NC_NOERR) (void)fprintf(stdout,"%s: DEBUG WARNING %s reports unexpected cumulative rcd = %i on exit. Please report this to NCO project.\n",nco_prg_nm_get(),fnc_nm,rcd);
 
+  return flg_chg; /* [flg] Attribute was altered */
 } /* end nco_aed_prc() */
 
+nco_bool /* [flg] Attribute was changed */
+nco_aed_prc_glb /* [fnc] Process attributes in root group */
+(const int nc_id, /* I [id] netCDF file ID */
+ const aed_sct aed, /* I [sct] Attribute-edit information */
+ const trv_tbl_sct * const trv_tbl) /* I [lst] Traversal table */ 
+{
+  /* Purpose: Process attributes in root group */
+  const char fnc_nm[]="nco_aed_prc_glb()"; /* [sng] Function name */
+  int grp_id; /* [id] Group ID */
+  nco_bool flg_chg=nco_bool_CEWI; /* [flg] Attribute was altered */
+
+  for(unsigned tbl_idx=0;tbl_idx<trv_tbl->nbr;tbl_idx++){
+    if(trv_tbl->lst[tbl_idx].nco_typ == nco_obj_typ_grp && !strcmp("/",trv_tbl->lst[tbl_idx].nm_fll)){
+      (void)nco_inq_grp_full_ncid(nc_id,trv_tbl->lst[tbl_idx].grp_nm_fll,&grp_id);
+      flg_chg=nco_aed_prc_wrp(grp_id,NC_GLOBAL,aed);
+      break;
+    } /* !grp */
+  } /* !tbl */ 
+
+  if(nco_dbg_lvl_get() > nco_dbg_var && !flg_chg) (void)fprintf(stderr,"%s: INFO %s reports attribute %s was not changed in root group\n",fnc_nm,nco_prg_nm_get(),aed.att_nm);
+
+  return flg_chg;
+} /* nco_aed_prc_glb() */
+
+nco_bool /* [flg] Attribute was changed */
+nco_aed_prc_grp /* [fnc] Process attributes in groups */
+(const int nc_id, /* I [id] netCDF file ID */
+ const aed_sct aed, /* I [sct] Attribute-edit information */
+ const trv_tbl_sct * const trv_tbl) /* I [lst] Traversal table */ 
+{
+  /* Purpose: Process attributes in groups */
+  const char fnc_nm[]="nco_aed_prc_grp()"; /* [sng] Function name */
+  int grp_id; /* [id] Group ID */
+  nco_bool flg_chg=False; /* [flg] Attribute was altered */
+
+  for(unsigned tbl_idx=0;tbl_idx<trv_tbl->nbr;tbl_idx++){
+    if(trv_tbl->lst[tbl_idx].nco_typ == nco_obj_typ_grp){
+      (void)nco_inq_grp_full_ncid(nc_id,trv_tbl->lst[tbl_idx].grp_nm_fll,&grp_id);
+      flg_chg|=nco_aed_prc_wrp(grp_id,NC_GLOBAL,aed);
+    } /* !group */
+  } /* end loop over tables */ 
+
+  if(nco_dbg_lvl_get() > nco_dbg_var && !flg_chg) (void)fprintf(stderr,"%s: INFO %s reports attribute %s was not changed in any group\n",fnc_nm,nco_prg_nm_get(),aed.att_nm);
+
+  return flg_chg;
+} /* nco_aed_prc_grp() */
+
+nco_bool /* [flg] Attribute was changed */
+nco_aed_prc_var_all /* [fnc] Process attributes in all variables */
+(const int nc_id, /* I [id] netCDF file ID */
+ const aed_sct aed, /* I [sct] Attribute-edit information */
+ const trv_tbl_sct * const trv_tbl) /* I [lst] Traversal table */ 
+{
+  /* Purpose: Process attributes in all variables */
+  const char fnc_nm[]="nco_aed_prc_var_all()"; /* [sng] Function name */
+  int grp_id; /* [id] Group ID */
+  int var_id; /* [id] Variable ID */
+  nco_bool flg_chg=False; /* [flg] Attribute was altered */
+  nco_bool var_fnd=False; /* [flg] Variable was found */
+
+  for(unsigned tbl_idx=0;tbl_idx<trv_tbl->nbr;tbl_idx++){
+    if(trv_tbl->lst[tbl_idx].nco_typ == nco_obj_typ_var){
+      (void)nco_inq_grp_full_ncid(nc_id,trv_tbl->lst[tbl_idx].grp_nm_fll,&grp_id);
+      (void)nco_inq_varid(grp_id,trv_tbl->lst[tbl_idx].nm,&var_id);
+      flg_chg|=nco_aed_prc_wrp(grp_id,var_id,aed);
+      var_fnd=True;
+    } /* !var */
+  } /* !tbl */ 
+
+  if(!var_fnd){
+    (void)fprintf(stderr,"%s: ERROR File contains no variables so variable attributes cannot be changed\n",nco_prg_nm_get());
+    nco_exit(EXIT_FAILURE);
+  } /* var_fnd */
+  if(nco_dbg_lvl_get() >= nco_dbg_var && !flg_chg) (void)fprintf(stderr,"%s: INFO %s reports attribute %s was not changed in any variable\n",fnc_nm,nco_prg_nm_get(),aed.att_nm);
+
+  return flg_chg;
+} /* nco_aed_prc_var_all() */
+
+nco_bool /* [flg] Attribute was changed */
+nco_aed_prc_var_nm /* [fnc] Process attributes in variables that match input name */
+(const int nc_id, /* I [id] netCDF file ID */
+ const aed_sct aed, /* I [sct] Attribute-edit information */
+ const trv_tbl_sct * const trv_tbl) /* I [lst] Traversal table */ 
+{
+  /* Purpose: Process attributes in variables that match input name (absolute or relative) */
+  const char fnc_nm[]="nco_aed_prc_var_nm()"; /* [sng] Function name */
+  int grp_id; /* [id] Group ID */
+  int var_id; /* [id] Variable ID */
+  nco_bool flg_chg=False; /* [flg] Attribute was altered */
+  nco_bool var_fnd=False; /* [flg] Variable was found */
+
+  /* Loop table (absolute name) */
+  for(unsigned tbl_idx=0;tbl_idx<trv_tbl->nbr;tbl_idx++){
+    trv_sct trv=trv_tbl->lst[tbl_idx];
+    if(trv.nco_typ == nco_obj_typ_var && !strcmp(aed.var_nm,trv.nm_fll)){
+      (void)nco_inq_grp_full_ncid(nc_id,trv.grp_nm_fll,&grp_id);
+      (void)nco_inq_varid(grp_id,trv.nm,&var_id);
+      flg_chg|=nco_aed_prc_wrp(grp_id,var_id,aed);
+      /* Only 1 match possible, return */
+      if(nco_dbg_lvl_get() >= nco_dbg_var && !flg_chg) (void)fprintf(stderr,"%s: INFO %s reports attribute %s was not changed for variable %s\n",fnc_nm,nco_prg_nm_get(),aed.att_nm,trv.grp_nm_fll);
+      return flg_chg;
+    } /* !var */
+  } /* !tbl */ 
+
+  /* Try relative variable names */
+  for(unsigned tbl_idx=0;tbl_idx<trv_tbl->nbr;tbl_idx++){
+    trv_sct trv=trv_tbl->lst[tbl_idx];
+    if(trv.nco_typ == nco_obj_typ_var && !strcmp(aed.var_nm,trv.nm)){
+      (void)nco_inq_grp_full_ncid(nc_id,trv.grp_nm_fll,&grp_id);
+      (void)nco_inq_varid(grp_id,trv.nm,&var_id);
+      flg_chg|=nco_aed_prc_wrp(grp_id,var_id,aed);
+      var_fnd=True;
+    } /* !var */
+  } /* !tbl */ 
+
+  /* Try absolute group names */
+  for(unsigned tbl_idx=0;tbl_idx<trv_tbl->nbr;tbl_idx++){
+    trv_sct trv=trv_tbl->lst[tbl_idx];
+    if(trv.nco_typ == nco_obj_typ_grp && !strcmp(aed.var_nm,trv.nm_fll)){
+      (void)nco_inq_grp_full_ncid(nc_id,trv.grp_nm_fll,&grp_id);
+      flg_chg|=nco_aed_prc_wrp(grp_id,NC_GLOBAL,aed);
+      if(nco_dbg_lvl_get() >= nco_dbg_var && !flg_chg) (void)fprintf(stderr,"%s: INFO %s reports attribute %s was not changed for group %s\n",fnc_nm,nco_prg_nm_get(),aed.att_nm,trv.grp_nm_fll);
+      /* Only 1 match possible, return */
+      return flg_chg;
+    } /* !var */
+  } /* !tbl */ 
+
+  /* Try relative group names */
+  for(unsigned tbl_idx=0;tbl_idx<trv_tbl->nbr;tbl_idx++){
+    trv_sct trv=trv_tbl->lst[tbl_idx];
+    if(trv.nco_typ == nco_obj_typ_grp && !strcmp(aed.var_nm,trv.nm)){
+      (void)nco_inq_grp_full_ncid(nc_id,trv.grp_nm_fll,&grp_id);
+      flg_chg|=nco_aed_prc_wrp(grp_id,NC_GLOBAL,aed);
+      var_fnd=True;
+    } /* !var */
+  } /* !tbl */ 
+
+  if(!var_fnd){
+    (void)fprintf(stderr,"%s: ERROR File contains no variables or groups that match name %s so attribute %s cannot be changed\n",nco_prg_nm_get(),aed.var_nm,aed.att_nm);
+    nco_exit(EXIT_FAILURE);
+  } /* var_fnd */
+  if(nco_dbg_lvl_get() >= nco_dbg_var && !flg_chg) (void)fprintf(stderr,"%s: INFO %s reports attribute %s was not changed for groups or variables that match relative name %s\n",fnc_nm,nco_prg_nm_get(),aed.att_nm,aed.var_nm);
+
+  return flg_chg;
+} /* nco_aed_prc_var_nm() */
+
+nco_bool /* [flg] Attribute was changed */
+nco_aed_prc_var_xtr /* [fnc] Process attributes in variables with extraction flag set */
+(const int nc_id, /* I [id] netCDF file ID */
+ const aed_sct aed, /* I [sct] Attribute-edit information */
+ const trv_tbl_sct * const trv_tbl) /* I [lst] Traversal table */ 
+{
+  /* Purpose: Process attributes in extracted variables */
+  const char fnc_nm[]="nco_aed_prc_var_xtr()"; /* [sng] Function name */
+  int grp_id; /* [id] Group ID */
+  int var_id; /* [id] Variable ID */
+  nco_bool flg_chg=False; /* [flg] Attribute was altered */
+  nco_bool var_fnd=False; /* [flg] Variable was found */
+
+  for(unsigned tbl_idx=0;tbl_idx<trv_tbl->nbr;tbl_idx++){
+    trv_sct trv=trv_tbl->lst[tbl_idx];
+    if(trv.nco_typ == nco_obj_typ_var && trv.flg_xtr){
+      (void)nco_inq_grp_full_ncid(nc_id,trv.grp_nm_fll,&grp_id);
+      (void)nco_inq_varid(grp_id,trv.nm,&var_id);
+      flg_chg|=nco_aed_prc_wrp(grp_id,var_id,aed);
+      var_fnd=True;
+    } /* !var */
+  } /* !tbl */ 
+
+  if(!var_fnd){
+    (void)fprintf(stderr,"%s: ERROR File contains no extracted variables or groups so attribute %s cannot be changed\n",nco_prg_nm_get(),aed.att_nm);
+    nco_exit(EXIT_FAILURE);
+  } /* var_fnd */
+  if(nco_dbg_lvl_get() >= nco_dbg_var && !flg_chg) (void)fprintf(stderr,"%s: INFO %s reports attribute %s was not changed in any extracted variables\n",fnc_nm,nco_prg_nm_get(),aed.att_nm);
+
+  return flg_chg;
+} /* nco_aed_prc_var_xtr() */
+
 void 
 nco_att_cpy  /* [fnc] Copy attributes from input netCDF file to output netCDF file */
 (const int in_id, /* I [id] netCDF input-file ID */
@@ -619,7 +928,7 @@ nco_prv_att_cat /* [fnc] Add provenance (history contents) of appended file to p
     att_sz=strlen(hst_sng_fmt)+strlen(time_stamp_sng)+strlen(fl_in)+strlen(att_nm_hst);
     hst_sng=(char *)nco_malloc((att_sz+1L)*sizeof(char));
     hst_sng[att_sz]='\0';
-    (void)sprintf(hst_sng,hst_sng_fmt,time_stamp_sng,fl_in,att_nm_hst);
+    (void)sprintf(hst_sng,hst_sng_fmt,fl_in,att_nm_hst);
   }else{
     /* Input file contains Global attribute "[hH]istory" */
     char hst_sng_fmt[]="Appended file %s had following \"%s\" attribute:\n%s\n";
@@ -1550,12 +1859,11 @@ nco_prs_rnm_lst /* [fnc] Set old_nm, new_nm elements of rename structure */
     
     lng_arg_1=comma_1_cp-rnm_arg[idx]; 
 
-    /* If new name is absolute path, get rid of it (ncrename does in place, same group, changes, so absolute path is redundant) */
+    /* Skip absolute path component (ncrename does in place, same group, changes, so absolute path is redundant) */
     char *abs_1_cp=strrchr(comma_1_cp,'/');
+
     /* Found path separator in new name (string after ',' ) */
-    if (abs_1_cp){
-      comma_1_cp=strrchr(comma_1_cp,'/');
-    }
+    if(abs_1_cp) comma_1_cp=strrchr(comma_1_cp,'/');
 
     lng_arg_2=rnm_arg[idx]+strlen(rnm_arg[idx])-comma_1_cp-1; 
     
@@ -1567,12 +1875,11 @@ nco_prs_rnm_lst /* [fnc] Set old_nm, new_nm elements of rename structure */
     
     /* Assign pointers to member of rnm_lst */
     rnm_lst[idx].old_nm=rnm_arg[idx];
-    rnm_lst[idx].new_nm=comma_1_cp+1;
+    rnm_lst[idx].new_nm=comma_1_cp+1L;
 
     /* NUL-terminate arguments */
     rnm_lst[idx].old_nm[lng_arg_1]='\0';
     rnm_lst[idx].new_nm[lng_arg_2]='\0';
-    
   } /* end loop over rnm_lst */
 
   if(nco_dbg_lvl_get() >= nco_dbg_io){
@@ -1591,13 +1898,16 @@ nco_vrs_att_cat /* [fnc] Add NCO version global attribute */
 {
   /* Purpose: Write NCO version information to global metadata */
   aed_sct vrs_sng_aed;
-  char att_nm[]="NCO";
-  char *vrs_cvs; /* [sng] Version according to CVS release tag */
+  char att_nm[]="NCO"; /* [sng] Name of attribute in which to store NCO version */
+  char vrs_git[]=TKN2SNG(VERSION); /* [sng] Version according to Git */
+  char *vrs_cvs; /* [sng] Version according to RCS/CVS-like release tag */
   char *vrs_sng; /* [sng] NCO version */
   ptr_unn att_val;
   
   vrs_cvs=cvs_vrs_prs();
+  
   vrs_sng=vrs_cvs;
+  vrs_sng=vrs_git;
 
   /* Insert thread number into value */
   att_val.cp=vrs_sng;
@@ -1610,9 +1920,9 @@ nco_vrs_att_cat /* [fnc] Add NCO version global attribute */
   /* Insert value into attribute structure */
   vrs_sng_aed.val=att_val;
   vrs_sng_aed.mode=aed_overwrite;
-  /* Write nco_openmp_thread_number attribute to disk */
+  /* Write NCO version attribute to disk */
   (void)nco_aed_prc(out_id,NC_GLOBAL,vrs_sng_aed);
-  vrs_sng=(char *)nco_free(vrs_sng);
+  // vrs_sng=(char *)nco_free(vrs_sng);
 
 } /* end nco_vrs_att_cat() */
 
@@ -1712,6 +2022,7 @@ nco_xcp_prc /* [fnc] Perform exception processing on this variable */
      Otherwise these variables would need a dummy dimension for time or char 
      For now, do not attempt to update values when var_sz != 8 */
   assert(var_typ == NC_CHAR);
+  CEWI_unused(var_typ);
   if(var_sz != 8) return;
   
   /* One block for each variable in exception list in nco_is_xcp() */
