@@ -46,11 +46,47 @@
 extern "C" {
 #endif /* __cplusplus */
 
-void
+nco_bool /* [flg] Attribute was changed */
+nco_aed_prc_wrp /* [fnc] Expand regular expressions then pass attribute edits to nco_aed_prc() */
+(const int nc_id, /* I [id] Input netCDF file ID */
+ const int var_id, /* I [id] ID of variable on which to perform attribute editing */
+ const aed_sct aed); /* I [sct] Attribute-edit information */
+
+  nco_bool /* [flg] Attribute was altered */
 nco_aed_prc /* [fnc] Process single attribute edit for single variable */
 (const int nc_id, /* I [id] Input netCDF file ID */
  const int var_id, /* I [id] ID of variable on which to perform attribute editing */
- const aed_sct aed); /* I [sct] Structure containing information necessary to edit */
+ const aed_sct aed); /* I [sct] Attribute-edit information */
+
+nco_bool /* [flg] Attribute was changed */
+nco_aed_prc_glb /* [fnc] Process attributes in root group */
+(const int nc_id, /* I [id] netCDF file ID */
+ const aed_sct aed, /* I [sct] Attribute-edit information */
+ const trv_tbl_sct * const trv_tbl); /* I [lst] Traversal table */ 
+
+nco_bool /* [flg] Attribute was changed */
+nco_aed_prc_grp /* [fnc] Process attributes in groups */
+(const int nc_id, /* I [id] netCDF file ID */
+ const aed_sct aed, /* I [sct] Attribute-edit information */
+ const trv_tbl_sct * const trv_tbl); /* I [lst] Traversal table */ 
+
+nco_bool /* [flg] Attribute was changed */
+nco_aed_prc_var_all /* [fnc] Process attributes in all variables */
+(const int nc_id, /* I [id] netCDF file ID */
+ const aed_sct aed, /* I [sct] Attribute-edit information */
+ const trv_tbl_sct * const trv_tbl); /* I [lst] Traversal table */ 
+
+nco_bool /* [flg] Attribute was changed */
+nco_aed_prc_var_xtr /* [fnc] Process attributes in variables that match table extraction flag */
+(const int nc_id, /* I [id] netCDF file ID */
+ const aed_sct aed, /* I [sct] Attribute-edit information */
+ const trv_tbl_sct * const trv_tbl); /* I [lst] Traversal table */ 
+
+nco_bool /* [flg] Attribute was changed */
+nco_aed_prc_var_nm /* [fnc] Process attributes in variables that match input name */
+(const int nc_id, /* I [id] netCDF file ID */
+ const aed_sct aed, /* I [sct] Attribute-edit information */
+ const trv_tbl_sct * const trv_tbl); /* I [lst] Traversal table */ 
 
 void 
 nco_att_cpy  /* [fnc] Copy attributes from input netCDF file to output netCDF file */
