@@ -22,14 +22,12 @@
 /* 3rd party vendors */
 #include <netcdf.h> /* netCDF definitions and C library */
 #include "nco_netcdf.h" /* NCO wrappers for netCDF C library */
-#ifdef ENABLE_ESMF
-# include <ESMC.h> /* ESMF definitions */
-#endif /* !ENABLE_ESMF */
 
 /* Personal headers */
 #include "nco.h" /* netCDF Operator (NCO) definitions */
 #include "nco_mmr.h" /* Memory management */
 #include "nco_omp.h" /* OpenMP utilities */
+#include "nco_sld.h" /* Swath-Like Data */
 #include "nco_sng_utl.h" /* String utilities */
 
 #ifdef __cplusplus
@@ -59,8 +57,9 @@ extern "C" {
 
   typedef enum nco_rgr_mpf_typ_enm{ /* [enm] Mapfile type enum */
     nco_rgr_mpf_nil=0,
-    nco_rgr_mpf_SCRIP,
     nco_rgr_mpf_ESMF,
+    nco_rgr_mpf_SCRIP,
+    nco_rgr_mpf_Tempest,
   } nco_rgr_mpf_typ_enm;
 
   typedef enum nco_rgr_grd_typ_enm{ /* [enm] Regrid type enum */
@@ -78,12 +77,19 @@ extern "C" {
     nco_grd_2D_ngl_eqi_fst, /* Equi-angle offset grid, FV staggered velocity grid (lat[0]=-89.X)): CIESIN/SEDAC, IGBP-DIS, TOMS AAI */
   } nco_grd_2D_typ_enm;
 
+  typedef enum nco_grd_xtn_enm{ /* [enm] Grid-extent enum */
+    nco_grd_xtn_nil=0,
+    nco_grd_xtn_glb,
+    nco_grd_xtn_rgn,
+  } nco_grd_xtn_enm;
+
   /* ESMF: The normalization attribute describes how the conservative weights are calculated, currently this is always set to "destarea" because this is the only option which we currently support. The setting "destarea" means that the conservative weights are calculated by dividing the area of the intersection of the source and destination cells by the area of the destination cell. This is set even when the weights are not conservative in which case it can be ignored. */
   typedef enum nco_rgr_nrm_typ_enm{ /* [enm] Normalization type enum */
     nco_rgr_nrm_nil=0,
     nco_rgr_nrm_fracarea, /* [] Allowed and explained by SCRIP */
     nco_rgr_nrm_destarea, /* [] Only option supported by ESMF, ignored when non-conservative methods used */
     nco_rgr_nrm_none, /* [] Allowed and explained by SCRIP */
+    nco_rgr_nrm_unknown, /* Tempest */
   } nco_rgr_nrm_typ_enm;
 
   /* ESMF: The map_method attribute indicates the interpolation type. The format of the interpolation weight file was developed by a group outside of ESMF, because of its use by utilities outside of ESMF control, the range of some of the meta data is constrained. The map_method is one of these. Because of this constraint, there is no map method corresponding to patch interpolation. A weight file generated with the "patch" interpolation method will have map_method set to "Bilinear remapping".  */
@@ -91,7 +97,8 @@ extern "C" {
     nco_rgr_mth_nil=0,
     nco_rgr_mth_conservative,
     nco_rgr_mth_bilinear,
-    nco_rgr_mth_none, /* []  */
+    nco_rgr_mth_none,
+    nco_rgr_mth_unknown, /* Tempest */
   } nco_rgr_mth_typ_enm;
 
   typedef struct{ /* nco_map_sct */
@@ -156,6 +163,10 @@ extern "C" {
   nco_grd_2D_sng /* [fnc] Convert two-dimensional grid-type enum to string */
   (const nco_grd_2D_typ_enm nco_grd_2D_typ); /* I [enm] Two-dimensional grid-type enum */
 
+  const char * /* O [sng] String describing grid extent */
+  nco_grd_xtn_sng /* [fnc] Convert two-dimensional grid-extent enum to string */
+  (const nco_grd_xtn_enm nco_grd_xtn); /* I [enm] Grid-extent enum */
+
   const char * /* O [sng] String describing grid conversion */
   nco_rgr_grd_sng /* [fnc] Convert grid conversion enum to string */
   (const nco_rgr_grd_typ_enm nco_rgr_grd_typ); /* I [enm] Grid conversion enum */
@@ -164,6 +175,10 @@ extern "C" {
   nco_rgr_mth_sng /* [fnc] Convert regridding method enum to string */
   (const nco_rgr_mth_typ_enm nco_rgr_mth_typ); /* I [enm] Regridding method enum */
 
+  const char * /* O [sng] String describing mapfile generator */
+  nco_rgr_mpf_sng /* [fnc] Convert mapfile generator enum to string */
+  (const nco_rgr_mpf_typ_enm nco_rgr_mpf_typ); /* I [enm] Mapfile generator enum */
+
   const char * /* O [sng] String describing regridding normalization */
   nco_rgr_nrm_sng /* [fnc] Convert regridding normalization enum to string */
   (const nco_rgr_nrm_typ_enm nco_rgr_nrm_typ); /* I [enm] Regridding normalization enum */
@@ -176,52 +191,6 @@ extern "C" {
   nco_tps_cmd_sng /* [fnc] Convert Tempest remap command enum to command name */
   (const nco_rgr_cmd_typ nco_rgr_cmd); /* I [enm] Tempest remap command enum */
 
-#ifdef ENABLE_ESMF
-  int /* O [enm] Return code */
-  nco_rgr_esmf /* [fnc] Regrid using ESMF library */
-  (rgr_sct * const rgr_nfo); /* I/O [sct] Regridding structure */
-
-  const char * /* O [sng] String version of ESMC_StaggerLoc enum */
-  nco_esmf_stg_lcn_sng /* [fnc] Convert ESMF stagger location enum to string */
-  (const int nco_esmf_stg_lcn); /* I [enm] ESMF stagger location enum ESMC_StaggerLoc */
-  
-  const char * /* O [sng] String version of ESMC_CoordSys_Flag enum */
-  nco_esmf_crd_sys_sng /* [fnc] Convert ESMF coordinate system enum to string */
-  (const int nco_esmf_crd_sys); /* I [enm] ESMF coordinate system enum ESMC_CoordSys_Flag */
-  
-  const char * /* O [sng] String version of ESMC_FileFormat_Flag */
-  nco_esmf_fl_fmt_sng /* [fnc] Convert ESMF file format to string */
-  (const int nco_esmf_fl_fmt); /* I [enm] ESMF file format enum ESMC_FileFormat_Flag */
-
-  const char * /* O [sng] String version of ESMC_GridItem_Flag enum */
-  nco_esmf_grd_itm_sng /* [fnc] Convert ESMF grid item enum to string */
-  (const int nco_esmf_grd_itm); /* I [enm] ESMF grid item enum ESMC_GridItem_Flag */
-  
-  const char * /* O [sng] String version of ESMC_LogMsgType_Flag enum */
-  nco_esmf_log_msg_sng /* [fnc] Convert ESMF log message type enum to string */
-  (const int nco_esmf_log_msg); /* I [enm] ESMF log message type enum ESMC_LogMsgType_Flag */
-  
-  const char * /* O [sng] String version of ESMC_PoleMethod_Flag enum */
-  nco_esmf_pll_mth_sng /* [fnc] Convert ESMF pole method type enum to string */
-  (const int nco_esmf_pll_mth); /* I [enm] ESMF pole method type enum ESMC_PoleMethod_Flag */
-
-  const char * /* O [sng] String version of ESMC_Region_Flag enum */
-  nco_esmf_rgn_flg_sng /* [fnc] Convert ESMF region flag enum to string */
-  (const int nco_esmf_rgn_flg); /* I [enm] ESMF region flag enum ESMC_Region_Flag */
-
-  const char * /* O [sng] String version of ESMC_RegridMethod_Flag enum */
-  nco_esmf_rgr_mth_sng /* [fnc] Convert ESMF regrid method type enum to string */
-  (const int nco_esmf_rgr_mth); /* I [enm] ESMF regrid method type enum ESMC_RegridMethod_Flag */
-
-  const char * /* O [sng] String version of ESMC_TypeKind_Flag enum */
-  nco_esmf_typ_knd_sng /* [fnc] Convert ESMF type kind enum to string */
-  (const int nco_esmf_typ_knd); /* I [enm] ESMF type kind enum ESMC_TypeKind_Flag */
-  
-  const char * /* O [sng] String version of ESMC_UnmappedAction_Flag enum */
-  nco_esmf_unm_act_sng /* [fnc] Convert ESMF unmapped action type enum to string */
-  (const int nco_esmf_unm_act); /* I [enm] ESMF unmapped action type enum ESMC_UnmappedAction_Flag */
-#endif /* !ENABLE_ESMF */
-
 #ifdef __cplusplus
 } /* end extern "C" */
 #endif /* __cplusplus */
