@@ -1,10 +1,10 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_var_rth.c,v 1.70 2014/06/15 21:06:24 zender Exp $ */
+/* $Header$ */
 
 /* Purpose: Variable arithmetic */
 
-/* Copyright (C) 1995--2014 Charlie Zender
+/* Copyright (C) 1995--2015 Charlie Zender
    This file is part of NCO, the netCDF Operators. NCO is free software.
-   You can redistribute and/or modify NCO under the terms of the 
+   You may redistribute and/or modify NCO under the terms of the 
    GNU General Public License (GPL) Version 3 with exceptions described in the LICENSE file */
 
 #include "nco_var_rth.h" /* Variable arithmetic */
@@ -15,7 +15,7 @@ nco_var_abs /* [fnc] Replace op1 values by their absolute values */
  const long sz, /* I [nbr] Size (in elements) of operand */
  const int has_mss_val, /* I [flg] Flag for missing values */
  ptr_unn mss_val, /* I [val] Value of missing value */
- ptr_unn op1) /* I [val] Values of first operand */
+ ptr_unn op1) /* I/O [val] Values of first operand */
 {
   /* Threads: Routine is thread safe and calls no unsafe routines */
   /* Purpose: Replace op1 values by their absolute values */
@@ -1096,7 +1096,7 @@ nco_var_max_bnr /* [fnc] Maximize two operands */
  ptr_unn op1, /* I [val] Values of first operand */
  ptr_unn op2) /* I/O [val] Values of second operand on input, values of maximum on output */
 {
-  /* Purpose: Find minimium value(s) of two operands and store result in second operand 
+  /* Purpose: Find maximum value(s) of two operands and store result in second operand 
      Operands are assumed to conform, be of same specified type, and have values in memory */
   long idx;
   
@@ -1263,7 +1263,7 @@ nco_var_min_bnr /* [fnc] Minimize two operands */
  ptr_unn op1, /* I [val] Values of first operand */
  ptr_unn op2) /* I/O [val] Values of second operand on input, values of minimum on output */
 {
-  /* Purpose: Find minimium value(s) of two operands and store result in second operand 
+  /* Purpose: Find minimum value(s) of two operands and store result in second operand 
      Operands are assumed to conform, be of same specified type, and have values in memory */
   long idx;
   
